@@ -23,7 +23,7 @@ class create_window:
         self.window.set_app_menu(menu)
         self.main_layout()
         if template != None:
-            print "filling values from template #%d (%.1f, %s)" % (template.id, template.points, template.notes)
+            print "filling values from template #%d (%.2f, %s)" % (template.id, template.points, template.notes)
             self.points_callback(template.points)
             notesbuffer = self.notes.get_buffer()
             notesbuffer.set_text(str(template.notes))
@@ -47,7 +47,9 @@ class create_window:
         self.left_column.pack_start(self.notes, True, True)
 
         calc_button = hildon.Button(gtk.HILDON_SIZE_AUTO, hildon.BUTTON_ARRANGEMENT_VERTICAL, 'Calculate')
-        calculator.instance.render_inputs(self.right_column, calc_button, self.points_callback)
+        #calculator.instance.render_inputs(self.right_column, calc_button, self.points_callback)
+        calc = calculator.calculator()
+        calc.render_inputs(self.right_column, calc_button, self.points_callback)
         self.right_column.pack_start(calc_button)
 
         points_container = gtk.HBox(homogeneous=True)
@@ -67,7 +69,7 @@ class create_window:
     def points_callback(self, points):
         import math
         if math.floor(points) != points:
-            self.points.set_text("%.1f" % points)
+            self.points.set_text("%.2f" % points)
         else:
             self.points.set_text("%d" % points)
 
