@@ -38,8 +38,8 @@ class create_window:
         weight_label.set_alignment(xalign=1, yalign=0.5)
         weight_container.pack_start(weight_label)
         self.weight = hildon.Entry(gtk.HILDON_SIZE_AUTO)
-        # TODO: How to use numeric with dots (to input floats)
-        self.weight.set_property('hildon-input-mode', gtk.HILDON_GTK_INPUT_MODE_NUMERIC)
+        # TODO: How to use (only) numeric with dots (to input floats)
+        self.weight.set_property('hildon-input-mode', gtk.HILDON_GTK_INPUT_MODE_NUMERIC | gtk.HILDON_GTK_INPUT_MODE_SPECIAL)
         weight_container.pack_start(self.weight)
         self.right_column.pack_start(weight_container)
 
